@@ -214,13 +214,6 @@ battery_device_cache_entry_update_all (GpmPower *power, GpmPowerDevice *entry)
 		if (exists) {
 			status->charge_rate_smoothed = status->charge_rate_raw;
 		}
-		/* FIXME: following can be removed if bug #5752 of hal on freedesktop
-		   gets fixed and is part of a new release of HAL and we depend on that
-		   version*/
-		if (exists && status->charge_rate_raw == 0) {
-			status->is_discharging = FALSE;
-			status->is_charging = FALSE;
-		}
 	}
 
 	/* sanity check that charge_level.percentage exists (if it should) */
@@ -356,13 +349,6 @@ battery_device_cache_entry_update_key (GpmPower		       *power,
 							power->priv->exp_ave_factor);
 		entry->charge_rate_previous = status->charge_rate_smoothed;
 
-		/* FIXME: following can be removed if bug #5752 of hal on freedesktop
-		   gets fixed and is part of a new release of HAL and we depend on that
-		   version */
-		if (status->charge_rate_raw == 0) {
-			status->is_discharging = FALSE;
-			status->is_charging = FALSE;
-		}
 	} else if (strcmp (key, "battery.charge_level.percentage") == 0) {
 		gpm_hal_device_get_int (power->priv->hal, udi, key, &status->percentage_charge);
 
@@ -607,27 +593,6 @@ gpm_power_get_num_devices_of_kind (GpmPower		*power,
 	return (g_slist_length (entry->devices));
 }
 
-/**
- * get_power_unit_suffix:
- * @unit: The unit type, e.g. GPM_POWER_UNIT_MWH
- * Return value: The localised device type. Do not free this.
- **/
-static const char *
-get_power_unit_suffix (GpmPowerUnit unit)
-{
-	const char *suffix;
-	if (unit == GPM_POWER_UNIT_MWH) {
-		suffix = "W";
-	} else if (unit == GPM_POWER_UNIT_PERCENT) {
-		suffix = "%";
-	} else if (unit == GPM_POWER_UNIT_CSR) {
-		suffix = "/7";
-	} else {
-		suffix = "?";
-	}
-	return suffix;
-}
-
 GpmPowerDevice *
 gpm_power_get_battery_device_entry (GpmPower	 *power,
 				    GpmPowerKind  battery_kind,
@@ -718,9 +683,11 @@ gpm_power_status_for_device_more (GpmPowerDevice *device)
 	if (device->technology) {
 		const char *technology;
 		if (strcasecmp (device->technology, "li-ion") == 0 ||
+		    strcasecmp (device->technology, "lithium-ion") == 0 ||
 		    strcasecmp (device->technology, "lion") == 0) {
 			technology = _("Lithium ion");
-		} else if (strcasecmp (device->technology, "pbac") == 0) {
+		} else if (strcasecmp (device->technology, "pbac") == 0 ||
+			   strcasecmp (device->technology, "lead-acid") == 0) {
 			technology = _("Lead acid");
 		} else {
 			gpm_warning ("Battery type %s not translated, please report!",
@@ -736,9 +703,10 @@ gpm_power_status_for_device_more (GpmPowerDevice *device)
 		g_string_append_printf (details, _("<b>Model:</b> %s\n"), device->model);
 	}
 	if (status->remaining_time > 0) {
-		const char *time;
+		char *time;
 		time = gpm_get_timestring (status->remaining_time);
 		g_string_append_printf (details, _("<b>Remaining time:</b> %s\n"), time);
+		g_free (time);
 	}
 	if (status->capacity > 0) {
 		const char *condition;
@@ -754,9 +722,8 @@ gpm_power_status_for_device_more (GpmPowerDevice *device)
 		g_string_append_printf (details, _("<b>Capacity:</b> %i%% (%s)\n"),
 					status->capacity, condition);
 	}
-	if (device->unit != GPM_POWER_UNIT_PERCENT) {
-		/* no point displaying these if we are measuring in percent */
-		suffix = get_power_unit_suffix (device->unit);
+	if (device->unit == GPM_POWER_UNIT_MWH) {
+		suffix = "W";
 		if (status->current_charge > 0) {
 			g_string_append_printf (details, _("<b>Current charge:</b> %.1f %s\n"),
 						status->current_charge / 1000.0f, suffix);
@@ -779,6 +746,17 @@ gpm_power_status_for_device_more (GpmPowerDevice *device)
 						status->charge_rate_smoothed / 1000.0f, suffix);
 		}
 	}
+	if (device->unit == GPM_POWER_UNIT_CSR) {
+		suffix = "/ 7";
+		if (status->current_charge > 0) {
+			g_string_append_printf (details, _("<b>Current charge:</b> %.1f %s\n"),
+						(float) status->current_charge, suffix);
+		}
+		if (status->design_charge > 0) {
+			g_string_append_printf (details, _("<b>Design charge:</b> %.1f %s\n"),
+						(float) status->design_charge, suffix);
+		}
+	}
 	/* remove the last \n */
 	g_string_truncate (details, details->len-1);
 	return details;
